@@ -15,6 +15,7 @@ from scrobbles.models import Scrobble
 from scrobbles.serializers import ScrobbleSerializer
 from videos.models import Series, Video
 from vrobbler.settings import DELETE_STALE_SCROBBLES
+from django.utils import timezone
 
 logger = logging.getLogger(__name__)
 
@@ -34,6 +35,18 @@ TRUTHY_VALUES = [
 class RecentScrobbleList(ListView):
     model = Scrobble
 
+    def get_context_data(self, **kwargs):
+        data = super().get_context_data(**kwargs)
+        now = timezone.now()
+        last_ten_minutes = timezone.now() - timedelta(minutes=10)
+        # Find scrobbles from the last 10 minutes
+        data['now_playing_list'] = Scrobble.objects.filter(
+            in_progress=True,
+            timestamp__gte=last_ten_minutes,
+            timestamp__lte=now,
+        )
+        return data
+
     def get_queryset(self):
         return Scrobble.objects.filter(in_progress=False).order_by(
             '-timestamp'
